<?php
/**
 * Main application class
 *
 * @package wp-engage-plus
 * @author InstaProduct
 * @link http://insta-product.com/
 */

//
//Include all function files
require_once( IPENG_LIB . '/config.php' );
require_once( IPENG_LIB . '/setting.php' );
require_once( IPENG_LIB . '/db.php' );
require_once( IPENG_LIB . '/font.php' );
require_once( IPENG_LIB . '/faicon.php' );
require_once( IPENG_LIB . '/model.php' );
require_once( IPENG_LIB . '/modelWidget.php' );
require_once( IPENG_LIB . '/tableMain.php' );
require_once( IPENG_LIB . '/Color.php' );
require_once( IPENG_APP . '/controller.php' );
require_once( IPENG_APP . '/viewer.php' );
require_once( IPENG_LIB . '/factory.php' );
require_once( IPENG_LIB . '/factoryPage.php' );

if ( ! class_exists( 'IPEng_App' ))
{
	class IPEng_App
	{
		//{{ run

		/**
		 * Run all functions
		 *
		 * @return void
		 */
		public static function run()
		{
			$hook = sanitize_title( IPENG_TITLE );

			//Install Plugin
			register_activation_hook( __FILE__, array( __CLASS__, 'install' ) );

			//Hook for plugin loaded
			add_action( 'plugins_loaded', array( __CLASS__, 'updateDb' ) );

			//
			//Admin init
			add_action( 'admin_init', array( __CLASS__, 'adminInit' ) );

			//
			//Register post type
			add_action( 'init', array( __CLASS__, 'registerPostType' ) );

			//
			//Register admin menu
			add_action( 'admin_menu', array( __CLASS__, 'addAdminMenu' ) );

			//
      //Rewrite Handler
      //
      add_action( 'init', array( __CLASS__, 'rewriteFlush' ) );
      add_action( 'pre_get_posts', array( __CLASS__, 'init' ) );

      //Render page
      add_action( 'template_redirect', array( __CLASS__, 'factoryPage' ) );

			//
			// Add meta box option
			//
			add_action( 'add_meta_boxes', array( __CLASS__, 'addMetaBox' ) );
			add_action( 'save_post', array( __CLASS__, 'savePost' ) );

			//Add widget via meta box
			add_action( 'wp_footer', array( __CLASS__, 'factoryWidget' ) );

			//
			//Add css
			add_action(
				'admin_print_styles-toplevel_page_' . IPENG_PAGENAME,
				array( __CLASS__, 'adminStyle' ),
				1100
			);
			add_action(
				'admin_print_styles-'.$hook.'_page_' . IPENG_PAGENAME . '-create',
				array( __CLASS__, 'adminStyle' ),
				1100
			);
			add_action(
				'admin_print_styles-'.$hook.'_page_' . IPENG_PAGENAME . '-setting',
				array( __CLASS__, 'adminStyle' ),
				1100
			);
			add_action(
				'admin_print_styles',
				array( __CLASS__, 'adminGlobalStyle' ),
				1000
			);

			//
			//Add javascript
			add_action(
				'admin_print_scripts-toplevel_page_' . IPENG_PAGENAME,
				array( __CLASS__, 'adminScript' ),
				1100
			);
			add_action(
				'admin_print_scripts-'.$hook.'_page_'.IPENG_PAGENAME. '-create',
				array( __CLASS__, 'adminScript' ),
				1100
			);
			add_action(
				'admin_print_scripts-'.$hook.'_page_'.IPENG_PAGENAME. '-setting',
				array( __CLASS__, 'adminScript' ),
				1100
			);
			add_action(
				'admin_print_scripts',
				array( __CLASS__, 'adminGlobalScript' ),
				1000
			);

			//
			//Front style & script
			add_action('wp_head', array( __CLASS__, 'publicStyle' ) );

			if ( ! is_admin() ) {
				add_action('wp_enqueue_scripts', array( __CLASS__, 'publicScript' ), 10 );
			}
		}

		//}}
		//{{ install

		/**
		 * Install plugin
		 *
		 * @return void
		 */
		public static function install()
		{
			//Install DB
			$db = new IPEng_Db();
			$db->install();

      //
      //Insert result page
      $dataPost = array(
        'post_status'  => 'publish',
        'post_type'    => 'ipeng_result_page',
        'post_author'  => 0,
        'post_title'   => 'Result Page',
        'post_slug'    => 'ipeng-result-page',
        'post_content' => ''
      );
      $result = wp_insert_post( $dataPost );
      //Save post id
      update_option( '__ipeng_result_page_id', $result );
		}

		//}}
		//{{ updateDb

		/**
		 * Update Db
		 *
		 * @return void
		 */
		public static function updateDb()
		{
			$db = new IPEng_Db();
			$db->update();
		}

		//}}
		//{{ adminInit

		/**
		 * Admin init
		 *
		 * @return void
		 */
		public static function adminInit()
		{
			/**
			 * Ajax handler
			 **/
			$controller = new IPEng_Controller();
			$controller->ajax();
		}

		//}}
		//{{ addAdminMenu

		/**
		 * Add admin menu
		 *
		 * @return void
		 */
		public static function addAdminMenu()
		{
			add_menu_page(
				IPENG_TITLE,
				IPENG_TITLE,
				'edit_posts',
				IPENG_PAGENAME,
				array( __CLASS__, 'dashboard' ),
				'dashicons-heart'
			);
			add_submenu_page(
				IPENG_PAGENAME,
				__( 'All Widgets', IPENG_SLUG ),
				__( 'All Widgets', IPENG_SLUG ),
				'edit_posts',
				IPENG_PAGENAME,
				array( __CLASS__, 'dashboard' )
			);
			add_submenu_page(
				IPENG_PAGENAME,
				__( 'Add Widget', IPENG_SLUG ),
				__( 'Add Widget', IPENG_SLUG ),
				'edit_posts',
				IPENG_PAGENAME . '-create',
				array( __CLASS__, 'create' )
			);
			add_submenu_page(
				IPENG_PAGENAME,
				__( 'Settings', IPENG_SLUG ),
				__( 'Settings', IPENG_SLUG ),
				'edit_posts',
				IPENG_PAGENAME . '-setting',
				array( __CLASS__, 'setting' )
			);
		}

		//}}
		//{{ dashboard

		/**
		 * All widgets page
		 *
		 * @return void
		 */
		public static function dashboard()
		{
			$viewer = new IPEng_Viewer();
			$viewer->dashboard();
		}

		//}}
		//{{ create

		/**
		 * Create new widget page
		 *
		 * @return void
		 */
		public static function create()
		{
			$viewer = new IPEng_Viewer();
			$viewer->create();
		}

		//}}
		//{{ setting

		/**
		 * Add administrator setting page
		 *
		 * @return void
		 */
		public static function setting()
		{
			$viewer = new IPEng_Viewer();
			$viewer->setting();
		}

		//}}
		//{{ registerPostType

		/**
		 * Register Post Type
		 *
		 * @return void
		 */
		public static function registerPostType()
		{
			$args	= array(
				'public' => false
			);
			register_post_type( 'ipeng_widget', $args );
		}

		//}}
		//{{ addMetaBox

		/**
		 * Add administrator meta box
		 *
		 * @return void
		 */
		public static function addMetaBox()
		{
			//
			//Add post/page metabox
			$screens = array( 'post', 'page' );
			foreach ($screens as $screen)
			{
				add_meta_box(
				'ipeng_metabox',
				__( 'WP Engage+ Settings', IPENG_SLUG ),
				array( __CLASS__, 'metaBoxContent' ),
				$screen
				);
			}
		}

		//}}
		//{{ metaBoxContent

		/**
		 * Content for administrator meta box
		 *
		 * @return void
		 */
		public static function metaBoxContent( $post )
		{
			$viewer = new IPEng_Viewer();
			$viewer->metabox( $post );
		}

		//}}
		//{{ savePost

		/**
		 * Save page/post meta box setting
		 *
		 * @return void
		 */
		public static function savePost( $post_id )
		{
			if ( isset( $_POST['post_type'] ) && 'page' == $_POST['post_type'] ) {
				if ( ! current_user_can( 'edit_page', $post_id ) ) {
					return;
				}
			} else {
				if ( ! current_user_can( 'edit_post', $post_id ) ) {
					return;
				}
			}
			// Check if the user intended to change this value.
			if ( ! isset( $_POST['ipeng_mbox_nonce'] ) ) {
				return;
			}
			$post_ID	= $_POST['post_ID'];
			//Widget
			$widgetId = sanitize_text_field( $_POST['ipeng_post_widget'] );
			update_post_meta( $post_ID, '__ipeng_post_widget', $widgetId );
		}

		//}}
		//{{ factoryWidget

		/**
		 * Render promo page
		 *
		 * @return void
		 */
		public static function factoryWidget()
		{
			//Factory
			$factory = new IPEng_Factory();
			$factory->render();
		}

		//}}
    //{{ init

    /**
     * Init request
     *
     * @return void
     */
    public static function init( $query )
    {
      $q = $query->query;
      if ( isset( $q['ipeng_result'] )) {
        $query->query_vars['post_type'] = 'ipeng_result_page';
        $query->query_vars['name']      = 'ipeng-result-page';
        $query->query_vars['pagename']  = 'ipeng-result-page';
        $query->query['pagename']       = 'ipeng-result-page';
        $query->query_vars['p']         = get_option( '__ipeng_result_page_id', 0 );
      }
    }

    //}}
    //{{ rewriteInit

    /**
     * Init rewrite rule
     *
     * @return void
     */
    public static function rewriteInit()
    {
      $base = get_option( '__ipeng_base_path', 'result' );
      add_rewrite_rule(
       $base . '/?$',
       'index.php?ipeng_result=1',
       'top'
      );
      add_rewrite_tag( '%ipeng_result%', '([1])');
    }

    //}}
    //{{ rewriteFlush

    /**
     * Flush rewrite rule
     *
     * @return void
     */
    public static function rewriteFlush()
    {
      $base = get_option( '__ipeng_base_path', 'result' );
      $old  = get_option( '__ipeng_base_path_old', 'result' );

      self::rewriteInit();

      if ( $base != $old ) {
         flush_rewrite_rules();
         update_option( '__ipeng_base_path_old', $base );
      }
    }

    //}}
    //{{ factoryPage

    /**
     * Render result page
     *
     * @return void
     */
    public static function factoryPage()
    {
      //Factory
      $factory = new IPEng_Factory_Page();
      $factory->render();
    }

		//}}
		//{{ adminStyle

		/**
		 * Add Css file
		 *
		 * @return void
		 */
		public static function adminStyle()
		{
			wp_deregister_style( 'ipeng-admin-style' );
			wp_register_style(
				'ipeng-admin-style',
				IPENG_BASE_URL . 'assets/css/admin.min.css',
				false,
				null
			);
			wp_enqueue_style('ipeng-admin-style');

			wp_deregister_style( 'ipeng-datetime-style' );
			wp_register_style(
				'ipeng-datetime-style',
				IPENG_BASE_URL . 'assets/css/jquery.datetimepicker.css',
				false,
				null
			);
			wp_enqueue_style('ipeng-datetime-style');
		}

		//}}
		//{{ adminGlobalStyle

		/**
		 * Add Css file to all pages
		 *
		 * @return void
		 */
		public static function adminGlobalStyle()
		{
			wp_deregister_style( 'ipeng-admin-global-style' );
			wp_register_style(
				'ipeng-admin-global-style',
				IPENG_BASE_URL . 'assets/css/admin-global.min.css',
				false,
				null
			);
			wp_enqueue_style('ipeng-admin-global-style');
		}

		//}}
		//{{ adminScript

		/**
		 * Add javascript file
		 *
		 * @return void
		 */
		public static function adminScript()
		{
		?>
			<script type="text/javascript">
				var ipeng_img_url = '<?php echo IPENG_BASE_URL . 'assets/img/'; ?>',
					ui_base_image	= '<?php echo IPENG_BASE_URL . 'assets/img/'; ?>',
					ui_message		 =
					{
						delete_confirm_title: '<?php _e( 'Delete Confirmation', IPENG_SLUG ); ?>',
						delete_confirm_info: '<?php _e( 'Are you sure doing this action?', IPENG_SLUG ); ?>'
					}
			</script>

			<?php
			wp_deregister_script('jquery-ui');
			wp_register_script(
				'jquery-ui',
				"http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jqueryui/1.10.4/jquery-ui.min.js",
				false,
				null
			);
			wp_enqueue_script('jquery-ui');

			wp_deregister_script('ipeng-admin-script');
			wp_enqueue_script(
				'ipeng-admin-script',
				IPENG_BASE_URL . 'assets/js/admin.js',
				array( 'jquery' ),
				1,
				true
			);
		}

		//}}
		//{{ adminGlobalScript

		/**
		 * Add javascript file to all pages
		 *
		 * @return void
		 */
		public static function adminGlobalScript()
		{
			wp_deregister_script('ipeng-admin-global-script');
			wp_enqueue_script(
				'ipeng-admin-global-script',
				IPENG_BASE_URL . 'assets/js/admin-global.min.js',
				array( 'jquery' ),
				1,
				true
			);
		}

		//}}
		//{{ publicStyle

		/**
		 * Print public style
		 *
		 * @return void
		 */
		public static function publicStyle()
		{
			global $post;
		?>
			<script type="text/javascript">
				var ipeng_ajaxurl	= "<?php echo admin_url( 'admin-ajax.php' ); ?>";
				var ipeng_img_url	= '<?php echo IPENG_BASE_URL . 'assets/img/'; ?>';
				var ipeng_post_id	= '<?php echo $post->ID; ?>';
			</script>
			<link media="all" type="text/css" href="<?php echo IPENG_BASE_URL; ?>assets/css/public.min.css" rel="stylesheet">

		<?php
		}

		//}}
		//{{ publicScript

		/**
		 * Print public script
		 *
		 * @return void
		 */
		public static function publicScript()
		{
			wp_enqueue_script('jquery');

			wp_deregister_script('jquery-ui');
			wp_register_script(
				'jquery-ui',
				"http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jqueryui/1.10.4/jquery-ui.min.js",
				false,
				null
			);
			wp_enqueue_script('jquery-ui');

			wp_deregister_script('ipeng-public-script');
			wp_enqueue_script(
				'ipeng-public-script',
				IPENG_BASE_URL . 'assets/js/public.min.js',
				array( 'jquery' ),
				1,
				true
			);
		}
		//}}
	}
}
