<?php
/**
 * Controller to handling saving choice data
 *
 * @package wp-page-takeover
 * @author InstaProduct
 * @link http://insta-product.com/
 */

if ( ! class_exists( 'IPEng_Ajax_Savechoice' ))
{
  class IPEng_Ajax_Savechoice
  {
    /**
     * Execution save options process
     *
     * @return void
     */
    public function exec()
    {
      $error    = true;
      $redirect = $result = '';

      if ( ! empty( $_POST['widget_id'] ) && 
           ! empty( $_POST['choice_id'] ) && 
           ! empty( $_POST['post_id'] ) && 
           ! empty( $_POST['result_action'] )
      ) {

        $model    = new IPEng_Model();
        $choiceId = absint( $_POST['choice_id'] );
        $widgetId = absint( $_POST['widget_id'] );
        $postId   = absint( $_POST['post_id'] );
        $widget   = get_post( $widgetId );
        $post     = get_post( $postId );
        $choice   = $model->getChoice( $choiceId );
        if ( $widget && $choice && $post )
        {
          //Save vote stat
          $action = apply_filters( 'pre_term_name', $_POST['result_action'] );
          $model->saveStat( $widget, 'vote' );
          //Save choice count
          $count = $choice->choi_count;
          $count++;
          $toUpdate = array(
            'choi_count' => $count
          );
          $model->updateChoice( $choice->choi_id, $toUpdate );

          if ( $action == 'redirect' ) {
            $redirect = $choice->choi_redirect;
          }
          elseif ( $action == 'page' ) {
            $redirect = $this->_getPermalink( $widget, $post );
          }

          //Save vote
          $this->_saveVote( $widget, $post, $choice );

          $error = false;
        }
      }

      if ( $error ) {
        $status = 0;
        $msg    = __( 'Failed to save choice data.', IPENG_SLUG );
      } 
      else {
        $status = 1;
        $msg    = __( 'Successfully to save choice data.', IPENG_SLUG );
      }
      echo json_encode( array(
        'status'    => $status,
        'message'   => $msg,
        'result'    => $result,
        'redirect'  => $redirect
      ) );
      die();
    }

    //}}
    //{{ _saveVote

    /**
     * Get page permalink
     *
     * @param object $widget
     * @param object $post
     * @param object $choice
     * @return void
     */
    protected function _saveVote( $widget, $post, $choice )
    {
      $result = 0;
      $model  = new IPEng_Model();
      if ( ! $model->getVoteByIp( $widget->ID, $_SERVER['REMOTE_ADDR'] ) )
      {
        global $user_ID;

        $toInsert = array(
          'widg_id'     => $widget->ID,
          'post_id'     => $post->ID,
          'choi_id'     => $choice->choi_id,
          'user_id'     => $user_ID,
          'vote_date'   => date( 'c' ),
          'vote_ip'     => $_SERVER['REMOTE_ADDR']
        );
        $result = $model->insertVote( $toInsert );
      }
      return $result;
    }
    //}}
    //{{ _getPermalink

    /**
     * Get page permalink
     *
     * @param object $widget
     * @param object $post
     * @return void
     */
    protected function _getPermalink( $widget, $post )
    {
      if ( get_option( 'permalink_structure' ) )  {
        $base = get_option( '__ipeng_base_path', 'result' );
        $link = get_home_url() . "/$base/?widget=" . $widget->ID . '&post=' . $post->ID;
      } else {
        $link = get_home_url() . '/?ipeng=1&widget=' . $widget->ID . '&post=' . $post->ID;
      }
      return $link;
    }

    /**
     * Get html result
     *
     * @param  object $widget
     * @return boolean
     */
    protected function _getHtmlResult( $widget )
    {
      $inputs  = '';
      $model   = new IPEng_Model();
      $choices = $model->getChoices( $widget->ID );
      if ( ! empty( $choices ))
      {
        $this->choices  = $choices;
        $this->widget   = $widget;
        $this->setting  = new IPEng_Setting( $widget->ID, '__ipeng-widget-setting' );
        $this->statData = $model->getStats( $widget->ID );

        ob_start();
        include( IPENG_VIEW . 'front/result.php' );
        $inputs = ob_get_contents();
        ob_end_clean();
      }
      return $inputs;
    }
  }
}
