<?php
/**
 * Controller to handling updating widget process
 *
 * @package wp-page-takeover
 * @author InstaProduct
 * @link http://insta-product.com/
 */

if ( ! class_exists( 'IPEng_Ajax_Update_widget' ))
{
	class IPEng_Ajax_Update_widget
	{
		/**
		 * Execution save options process
		 *
		 * @return void
		 */
		public function exec()
		{
			$redirect = false;
			$is_add   = false;
			$error    = true;
			if ( ! empty( $_POST['isadd'] )) {
					$is_add = true;
			}
			if ( ! empty( $_POST['widget_id'] )) {
					$widgetId = absint( $_POST['widget_id'] );
					if ( $widget = get_post( $widgetId ) ) {
							$this->_updateWidget( $widget );
					} else {
							$widgetId = 0;
					}
			} else {
					$widgetId = $this->_addWidget();
			}
			if ( $widgetId )
			{
					$error = false;
					$model = new IPEng_Model_Widget();
					$model->saveSetting( $widgetId );
			}
			if ( $error ) {
					$status   = 0;
					$widgetId  = 0;
					if ( $is_add ) {
							$message = __( 'Failed create widget.', IPENG_SLUG );
					} else {
							$message = __( 'Failed save widget.', IPENG_SLUG );
					}
			} else {
					$status = 1;
					if ( $is_add ) {
							$message  = __( 'Successfully created widget.', IPENG_SLUG );
							$redirect = admin_url() . 'admin.php?page=' . IPENG_PAGENAME . '&action=edit&id=' . $widgetId . '&create=1';
					} else {
							$message = __( 'Successfully saved widget.', IPENG_SLUG );
					}
			}

			$inputs = $this->_getRedirectInputs( $widgetId );
			$result = array(
					'status'    			=> $status,
					'message'   			=> $message,
					'widgetid'  			=> $widgetId,
					'redirect_inputs'	=> $inputs
			);
			if ( $redirect ) {
					$result['redirect'] = $redirect;
			}
			echo json_encode( $result );
			die();
		}

		/**
		 * Add new widget
		 *
		 * @return int
		 */
		protected function _addWidget()
		{
			global $user_ID;

			if ( empty( $_POST['widget_name'] )) {
					$title = 'Unknown';
			} else {
					$title = apply_filters( 'single_post_title', $_POST['widget_name'] );
			}

			$dataPost = array(
				'post_status'  => 'publish',
				'post_type'    => 'ipeng_widget',
				'post_author'  => $user_ID,
				'post_title'   => $title,
				'post_content' => ''
			);
			$result = wp_insert_post( $dataPost );
			return $result;
		}

		/**
		 * Update widget
		 *
		 * @param  object $widget
		 * @return boolean
		 */
		protected function _updateWidget( $widget )
		{
			$result   = 0;
			$dataPost = array();
			if ( ! empty( $_POST['widget_name'] ) && $_POST['widget_name'] != $widget->post_title ) {
					$dataPost['post_title'] = apply_filters( 'single_post_title', $_POST['widget_name'] );
			}
			if ( ! empty( $dataPost )) {
					$dataPost['ID'] = $widget->ID;
					$result = wp_update_post( $dataPost );
			}
			return $result;
		}

		/**
		 * Get redirect inputs
		 *
		 * @param  object $widget
		 * @return boolean
		 */
		protected function _getRedirectInputs( $widgetId )
		{
			$inputs  = '';
			$model   = new IPEng_Model();
			$choices = $model->getChoices( $widgetId );
			if ( ! empty( $choices ))
			{
				$this->choices = $choices;

				ob_start();
	      include( IPENG_VIEW . 'admin/widget/redirect_inputs.php' );
	      $inputs = ob_get_contents();
	      ob_end_clean();
			}
			return $inputs;
		}
	}
}
