<?php
if ( ! class_exists( 'IPEng_Db' ))
{
	/**
	 * Class for manage plugin database
	 */
	class IPEng_Db
	{
		/**
		 * Take db version
		 *
		 * @var string
		 */
		public $version = '1.0';

		/**
		 * Class construct
		 *
		 * @return void
		 */
		public function __construct()
		{
			global $ipeng_db_version;
			$ipeng_db_version = $this->version;
		}

		/**
		 * Database query
		 *
		 * @return string
		 */
		public function query_stats()
		{
			global $wpdb;

			$table_name = $wpdb->prefix . 'ipeng_stat';
			$sql = "CREATE TABLE $table_name (
									stat_id       int(11)             NOT NULL AUTO_INCREMENT,
									widg_id       int(11)             NOT NULL,
									stat_date     datetime  DEFAULT '0000-00-00 00:00:00' NOT NULL,
									stat_view     int(11)             NOT NULL,
									stat_vote     int(11)             NOT NULL,
									stat_share    int(11)             NOT NULL,
							PRIMARY KEY stat_id (stat_id),
							KEY widget_id (widg_id)
			);";

			return $sql;
		}

		/**
		 * Database query choice
		 *
		 * @return string
		 */
		public function query_choice()
		{
			global $wpdb;

			$table_name = $wpdb->prefix . 'ipeng_choice';
			$sql = "CREATE TABLE $table_name (
									choi_id       	int(11)             NOT NULL AUTO_INCREMENT,
									widg_id         int(11)             NOT NULL,
									choi_title  		varchar(200)        NOT NULL,
									choi_color  		varchar(10)         NOT NULL,
									choi_icon   		varchar(50)         NOT NULL,
									choi_redirect   varchar(200)        NOT NULL,
									choi_created  	datetime  DEFAULT '0000-00-00 00:00:00' NOT NULL,
									choi_count   		int(11)        			NOT NULL,
									choi_order   		smallint(11)        NOT NULL,
									choi_status 		tinyint(11)         NOT NULL,
							PRIMARY KEY choice_id (choi_id),
							KEY widget_id (widg_id)
			);";

			return $sql;
		}

		/**
		 * Database query vote
		 *
		 * @return string
		 */
		public function query_vote()
		{
			global $wpdb;

			$table_name = $wpdb->prefix . 'ipeng_vote';
			$sql = "CREATE TABLE $table_name (
									vote_id       	int(11)             NOT NULL AUTO_INCREMENT,
									widg_id         int(11)             NOT NULL,
									post_id         int(11)             NOT NULL,
									choi_id         int(11)             NOT NULL,
									user_id         int(11)             NOT NULL,
									vote_date      	datetime  DEFAULT '0000-00-00 00:00:00' NOT NULL,
									vote_ip     		varchar(50)         NOT NULL,
							PRIMARY KEY choice_id (vote_id),
							KEY widget_id (widg_id),
							KEY post_id (post_id),
							KEY choice_id (choi_id),
							KEY user_id (user_id)
			);";

			return $sql;
		}

		/**
		 * Database query
		 *
		 * @return string
		 */
		public function query()
		{
			$sql  = '';
			$sql .= $this->query_stats();
			$sql .= $this->query_choice();
			$sql .= $this->query_vote();
			return $sql;
		}

		/**
		 * install
		 *
		 * @return void
		 */
		public function install()
		{
			global $wpdb, $ipeng_db_version;
			$installed_ver = get_option( "ipeng_db_version" );

			if( ! $installed_ver || ( $installed_ver != $ipeng_db_version ) )
			{
				$sql = $this->query();

				require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
				dbDelta( $sql );

				update_option( "ipeng_db_version", $ipeng_db_version );
			}
		}

		/**
		 * update
		 *
		 * @return void
		 */
		public function update()
		{
			global $ipeng_db_version;
			if ( get_site_option( 'ipeng_db_version' ) != $ipeng_db_version ) {
				$this->install();
			}
		}
	}

}
?>
