<?php
if ( ! class_exists( 'IPEng_Factory' ))
{
  /**
   * Widget factory class
   *
   * @package wp-page-takeover
   * @author InstaProduct
   * @link http://insta-product.com/
   */

  class IPEng_Factory extends IPEng_Viewer
  {
    //{{ __construct

    /**
     * Class constructor
     *
     * @return void
     */
    public function __construct()
    {
    }

    //}}
    //{{ render

    /**
     * Render page
     *
     * @return string
     */
    public function render()
    {
      $widget = $this->_getWidget();

      if ( $widget && $widget->post_status == 'publish' )
      {
        $this->widget  = $widget;
        $this->setting = new IPEng_Setting( $widget->ID, '__ipeng-widget-setting' );

        //
        //Check restricted
        $restricted = false;
        if ( empty( $user_ID ) && $this->setting->getSetting( 'restricted', 'false' ) == 'true' ) {
          $restricted = true;
        }

        $model = new IPEng_Model();

        //
        //Check ip
        $voted = false;
        $vote  = false;
        $testMode = $this->setting->getSetting( 'test_mode', 'false' );
        if ( $testMode == 'false' )
        {
          $ip = $_SERVER['REMOTE_ADDR'];
          if ( $vote = $model->getVoteByIP( $widget->ID, $ip ) ) {
            $voted = true;
          }
        }
        $this->voteData = $vote;
        $this->isVoted  = $voted;

        //
        //Get choices
        $this->choices  = $model->getChoices( $widget->ID );
        $this->statData = $model->getStats( $widget->ID );

        //Render view
        if ( ! $restricted ) {
          $this->view( 'front/widget' );
        }
      }
    }

    //}}
    //{{ previewWidget

    /**
     * Bar preview viewer
     *
     * @param  array $widget
     * @return void
     */
    public function previewWidget( $widget )
    {
      $output = '';
      if ( $widget )
      {
        $this->widget     = $widget;
        $this->isPreview  = true;
        $this->setting    = new IPEng_Setting( $widget->ID, '__ipeng-widget-setting' );
        //
        //Get choices
        $model = new IPEng_Model();
        $this->choices  = $model->getChoices( $widget->ID );
        $this->statData = $model->getStats( $widget->ID );
        
        //Render view
        ob_start();
        $this->view( 'front/widget' );
        $output = ob_get_contents();
        ob_end_clean();
      }
      echo $output;
    }

    //}}
    //{{ _getWidget

    /**
     * Get widget
     *
     * @return void
     */
    protected function _getWidget()
    {
      global $post;

      $widgetId = 0;
      $widget   = false;
      $type     = '';
      $general  = get_option( '__ipeng_general_widget' );
      if ( ! empty( $general )) {
        $widgetId = absint( $general );
        $type  = 'general';
      }
      else
      {
        if ( ( is_page() || is_single() ) && ! empty( $post )) {
          $widgetId = get_post_meta( $post->ID, '__ipeng_post_widget', true );
          $type  = 'page';
        } elseif ( is_home() ) {
          $widgetId = get_option( '__ipeng_home_widget' );
          $type  = 'home';
        }
      }
      if ( ! empty( $widgetId )) {
        $widget = get_post( $widgetId );
      }
      return $widget;
    }

    //}}
    //{{ getYoutubeUrl

    /**
     * Get youtube url
     *
     * @return string
     */
    public function getYoutubeUrl( $setting )
    {
      $url  = $setting->getSetting( 'youtube_url' );
      $time = $setting->getSetting( 'youtube_start', 0 );
      $auto = $setting->getSetting( 'video_autoplay', 'false' );
      if ( $url )
      {
        if ( strpos( $url, 'embed' ) === false ) {
          if ( strpos( $url, 'watch' ) !== false ) {
            $id     = '';
            $parsed = parse_url( $url );
            if ( ! empty( $parsed['query'] )) {
                parse_str( $parsed['query'], $args );
                if ( ! empty( $args['v'] )) {
                    $id = $args['v'];
                }
            }
            $url = 'http://youtube.com/embed/' . $id;
          }
          elseif ( strpos( $url, 'youtu.be' ) !== false ) {
            $id     = '';
            $parsed = parse_url( $url );
            if ( ! empty( $parsed['path'] )) {
              $id = trim( $parsed['path'], '/' );
            }
            $url = 'http://youtube.com/embed/' . $id;
          }
        }
        if ( $auto == 'true' ) {
          $astart = 1;
        } else {
          $astart = 0;
        }
        $url .= '?autoplay=' . $astart . '&rel=0';
        if ( ! empty( $time )) {
          $url .= '&start=' . $time;
        }
      }
      return $url;
    }

    //}}
    //{{ getShareLink

    /**
     * Get share link
     *
     * @param  string $type
     * @param  object $post
     * @return string
     */
    public function getShareLink( $type, $post )
    {
      $pagetitle = urlencode( $post->post_title );
      $pageurl   = urlencode( get_post_permalink( $post ) );
      $actions   =  array(
        'facebook'      => 'http://www.facebook.com/share.php?u=' . $pageurl,
        'twitter'       => 'https://twitter.com/share?url=' . $pageurl . '&text=' . $pagetitle,
        'googleplus'    => 'https://plusone.google.com/_/+1/confirm?hl=en&url=' . $pageurl,
        'pinterest'     => 'http://pinterest.com/pin/create/button/?url=' . $pageurl . '&media=&description=' . $pagetitle,
        'linkedin'      => 'http://www.linkedin.com/shareArticle?mini=true&url=' . $pageurl .'&title=' . $pagetitle,
        'tumblr'        => 'http://www.tumblr.com/share?v=3&u=' . $pageurl,
        'stumbleupon'   => 'http://www.stumbleupon.com/submit?url=' . $pageurl . '&title=' . $pagetitle,
        'digg'          => 'http://digg.com/submit?url=' . $pageurl . '&title=' . $pagetitle,
        'email'         => 'mailto:?subject=' . $pagetitle
      );
      $link = '#';
      if ( array_key_exists( $type, $actions )) {
        $link = $actions[$type];
      }
      return $link;
    }

    //}}
  }
}
