<?php
/**
 * Class model widget
 *
 * @package wp-page-takeover
 * @author InstaProduct
 * @link http://insta-product.com/
 */

if ( ! class_exists( 'IPEng_Model' )) {

  /**
   * Class model widget
   */
  class IPEng_Model
  {
		/**
		 * Get Choices
		 *
		 * @return int   $widgetId
		 * @return array
		 */
		public function getChoices( $widgetId )
		{
			global $wpdb;
			$table  = $wpdb->prefix . 'ipeng_choice';
			$query  = "
					SELECT * FROM $table
					WHERE
							widg_id = $widgetId
					ORDER BY choi_order
			";
			$results = $wpdb->get_results( $query );
			return $results;
		}

		/**
		 * Get widget stats
		 *
		 * @return int   $widgetId
		 * @return array
		 */
		public function getWidgetStats( $widgetId )
		{
			global $wpdb;
			$table  = $wpdb->prefix . 'ipeng_stat';
			$query  = "
					SELECT * FROM $table
					WHERE
							widg_id = $widgetId
			";
			$results = $wpdb->get_results( $query );
			return $results;
		}

		/**
		 * Get Choice
		 *
		 * @return int   $choiceId
		 * @return array
		 */
		public function getChoice( $choiceId )
		{
			global $wpdb;
			$table  = $wpdb->prefix . 'ipeng_choice';
			$query  = "
					SELECT * FROM $table
					WHERE
							choi_id = $choiceId
			";
			$results = $wpdb->get_row( $query );
			return $results;
		}

		/**
		 * Get Stats
		 *
		 * @return int   $widgetId
		 * @return array
		 */
		public function getStats( $widgetId )
		{
			global $wpdb;
			$table  = $wpdb->prefix . 'ipeng_stat';
			$query  = "
					SELECT * FROM $table
					WHERE
							widg_id = $widgetId
			";
			$results = $wpdb->get_row( $query );
			return $results;
		}

		/**
		 * Insert Choice
		 *
		 * @param  array $data
		 * @param  array $format
		 * @return void
		 */
		public function insertChoice( $data, $format = array() )
		{
				global $wpdb;
				$table  = $wpdb->prefix . 'ipeng_choice';
				$data   = (array)$data;

				$result = $wpdb->insert( $table, $data, $format );
				if ( $result ) {
						return $wpdb->insert_id;
				}
				return false;
		}

		/**
		 * Update Choice
		 *
		 * @param  int   $id
		 * @param  array $data
		 * @return void
		 */
		public function updateChoice( $id, $data )
		{
				global $wpdb;
				$table  = $wpdb->prefix . 'ipeng_choice';
				$data   = (array)$data;
				$where  = array(
						'choi_id' => absint( $id )
				);
				$result = $wpdb->update( $table, $data, $where );
				return $result;
		}

		/**
		 * Delete Choice
		 *
		 * @param  int   $id
		 * @return void
		 */
		public function deleteChoice( $id )
		{
			global $wpdb;
			$table  = $wpdb->prefix . 'ipeng_choice';
			$where  = array(
					'choi_id' => absint( $id )
			);
			$result = $wpdb->delete( $table, $where );
			return $result;
		}

		/**
		 * Delete Choices
		 *
		 * @param  int   $widgetId
		 * @return void
		 */
		public function deleteChoices( $widgetId )
		{
			global $wpdb;
			$table  = $wpdb->prefix . 'ipeng_choice';
			$where  = array(
					'widg_id' => absint( $widgetId )
			);
			$result = $wpdb->delete( $table, $where );
			return $result;
		}

		/**
     * Get stat by widget date
     *
     * @param  int $widgetId
     * @return array
     */
    public function getStatByWidget( $widgetId )
    {
      global $wpdb;

      $widgetId = absint( $widgetId );
      $table    = $wpdb->prefix . 'ipeng_stat';
      $sql      = "
          SELECT *
          FROM `$table`
          WHERE widg_id = $widgetId
      ";
      $results = $wpdb->get_row( $sql );
      return $results;
    }

		/**
     * Do save statistic
     *
     * @param object $widget
     * @param string $type
     * @param int    $count
     * @return void
     */
    public function saveStat( $widget, $type, $count = 1 )
    {
      $_types = array(
        'view',
        'vote',
        'share'
      );
      $key = 'stat_';
      if ( in_array( $type, $_types )) {
        $key .= $type;
      }
      $data = array();
      if ( $stat = $this->getStatByWidget( $widget->ID ))
      {
        $ccount = 0;
        if ( isset( $stat->$key )) {
          $ccount = $stat->$key;
        }
        $data[$key] = $ccount + $count;
        $this->updateStat( $stat->stat_id, $data );
      }
      else {
        $data['widg_id']   = $widget->ID;
        $data['stat_date'] = date( 'Y-m-d 00:00:00' );
        $data[$key]        = $count;
        $this->insertStat( $data );
      }
    }

		/**
		 * Insert Stat
		 *
		 * @param  array $data
		 * @param  array $format
		 * @return void
		 */
		public function insertStat( $data, $format = array() )
		{
				global $wpdb;
				$table  = $wpdb->prefix . 'ipeng_stat';
				$data   = (array)$data;

				$result = $wpdb->insert( $table, $data, $format );
				if ( $result ) {
						return $wpdb->insert_id;
				}
				return false;
		}

		/**
		 * Update Stat
		 *
		 * @param  int   $id
		 * @param  array $data
		 * @return void
		 */
		public function updateStat( $id, $data )
		{
				global $wpdb;
				$table  = $wpdb->prefix . 'ipeng_stat';
				$data   = (array)$data;
				$where  = array(
						'stat_id' => absint( $id )
				);
				$result = $wpdb->update( $table, $data, $where );
				return $result;
		}

		/**
		 * Delete Stat
		 *
		 * @param  int   $id
		 * @return void
		 */
		public function deleteStat( $id )
		{
			global $wpdb;
			$table  = $wpdb->prefix . 'ipeng_stat';
			$where  = array(
					'stat_id' => absint( $id )
			);
			$result = $wpdb->delete( $table, $where );
			return $result;
		}

		/**
		 * Get Vote By IP
		 *
		 * @return int    $widgetId
		 * @return string $ip
		 * @return array
		 */
		public function getVoteByIP( $widgetId, $ip )
		{
			global $wpdb;
			$widgetId = absint( $widgetId );
			$table    = $wpdb->prefix . 'ipeng_vote';
			$query    = "
					SELECT * FROM $table
					WHERE
							widg_id = $widgetId AND
							vote_ip = '$ip'
			";
			$results = $wpdb->get_row( $query );
			return $results;
		}

		/**
		 * Insert Vote
		 *
		 * @param  array $data
		 * @param  array $format
		 * @return void
		 */
		public function insertVote( $data, $format = array() )
		{
				global $wpdb;
				$table  = $wpdb->prefix . 'ipeng_vote';
				$data   = (array)$data;

				$result = $wpdb->insert( $table, $data, $format );
				if ( $result ) {
						return $wpdb->insert_id;
				}
				return false;
		}

		/**
		 * Update Vote
		 *
		 * @param  int   $id
		 * @param  array $data
		 * @return void
		 */
		public function updateVote( $id, $data )
		{
				global $wpdb;
				$table  = $wpdb->prefix . 'ipeng_vote';
				$data   = (array)$data;
				$where  = array(
						'vote_id' => absint( $id )
				);
				$result = $wpdb->update( $table, $data, $where );
				return $result;
		}

		/**
		 * Delete Vote
		 *
		 * @param  int   $id
		 * @return void
		 */
		public function deleteVote( $id )
		{
			global $wpdb;
			$table  = $wpdb->prefix . 'ipeng_vote';
			$where  = array(
					'vote_id' => absint( $id )
			);
			$result = $wpdb->delete( $table, $where );
			return $result;
		}
	}
}
