<?php
if ( ! class_exists( 'IPEng_Viewer' ))
{
  /**
   * Viewer class
   *
   * @package wp-engage-plus
   * @author InstaProduct
   * @link http://insta-product.com/
   */

  class IPEng_Viewer
  {
    //{{ dashboard

    /**
     * Dashboard viewer
     *
     * @return void
     */
    public function dashboard()
    {
      $this->pageId = IPENG_PAGENAME;

      //Edit widget
      if ( isset( $_GET['action'] ) && $_GET['action'] == 'edit' )
      {
        if ( empty( $_GET['id'] )) {
          wp_die( __('You attempted to edit an item that doesn&#8217;t exist. Perhaps it was deleted?', IPENG_SLUG ) );
        }
        $id = absint( $_GET['id'] );
        if ( ! $widget = get_post( $id ) ) {
          wp_die( __('You attempted to edit an item that doesn&#8217;t exist. Perhaps it was deleted?', IPENG_SLUG ) );
        }
        $this->_manageWidget( $widget );
      }
      //Widget dashboard
      else {
        $this->view( 'admin/dashboard' );
      }
    }

    //}}
    //{{ create

    /**
     * Create widget viewer
     *
     * @return void
     */
    public function create()
    {
      $this->pageId = IPENG_PAGENAME . '-create';
			$this->_manageWidget();
    }

    //}}
    //{{ _manageWidget

    /**
     * Manage widget
     *
     * @param object $widget
     * @return void
     */
    protected function _manageWidget( $widget = false )
    {
      //
      //Including script
      wp_enqueue_media();
      wp_enqueue_script('wp-color-picker');
      wp_enqueue_style('wp-color-picker');

      $widgetId = 0;
      if ( $widget ) {
        $widgetId = $widget->ID;
      }
      $setting    = new IPEng_Setting( $widgetId, '__ipeng-widget-setting' );
      $formAction = admin_url( 'admin-ajax.php' ) . '?doajax=1&ipeng=1&action=update_widget';
      if ( $widget )
      {
        $pageTitle   = __( 'Edit Widget', IPENG_SLUG );
        $submitLabel = __( 'Save Change', IPENG_SLUG );
        $submitId    = 'ipeng-edit-widget';
        $formId      = 'ipeng-form-widget-update';
        $submitIcon  = 'floppy-o';
        $pageId      = IPENG_PAGENAME;

      } else
      {
        $pageTitle   = __( 'Add Widget', IPENG_SLUG );
        $submitLabel = __( 'Add Widget', IPENG_SLUG );
        $submitId    = 'ipeng-add-widget';
        $formId      = 'ipeng-form-widget-add';
        $submitIcon  = 'plus-circle';
        $pageId      = IPENG_PAGENAME;
      }
      $this->pageId      = $pageId;
      $this->pageTitle   = $pageTitle;
      $this->submitLabel = $submitLabel;
      $this->submitId    = $submitId;
      $this->formId      = $formId;
      $this->submitIcon  = $submitIcon;
      $this->setting     = $setting;
      $this->widget      = $widget;
      $this->widgetId    = $widgetId;
      $this->formAction  = $formAction;

			//
			//Get choices
			$model    = new IPEng_Model();
			$choices  = array();
			$statView = $statShare = $statVote = 0;
			if ( ! empty( $widget ))
			{
				$choices = $model->getChoices( $widget->ID );
				//
				//Get statistic values
				if ( $statData = $model->getStats( $widget->ID )) {
					$statView  = $statData->stat_view;
					$statVote  = $statData->stat_vote;
					$statShare = $statData->stat_share;
				}
			}
			$this->choices = $choices;
			$this->statView  = $statView;
			$this->statVote  = $statVote;
			$this->statShare = $statShare;


      $tab = 'ipeng-section-general';
      if ( ! empty( $_REQUEST['tab'] )) {
        $tab = $_REQUEST['tab'];
      }
      $this->tab = $tab;

      //Render view
      $this->view( 'admin/widget/main' );
    }

    //}}
    //{{ setting

    /**
     * Setting page viewer
     *
     * @return void
     */
    public function setting()
    {
      $this->pageId  = IPENG_PAGENAME . '-setting';
      $this->widgets = $this->_getWidgets();
      //Render view
      $this->view( 'admin/setting' );
    }

    //}}
    //{{ metabox

    /**
     * Metabox page viewer
     *
     * @return void
     */
    public function metabox( $post )
    {
      $this->post    = $post;
      $this->widgets = $this->_getWidgets();

      //Render view
      $this->view( 'admin/metabox' );
    }

    //}}
    //{{ view

    /**
     * Get admin view file
     *
     * @param string $filename
     * @return void
     */
    public function view( $filename )
    {
      $path  = IPENG_VIEW;
      $path .= strtolower( $filename ) . '.php';
      if ( file_exists( $path )) {
        include( $path );
      }
    }

    //}}
    //{{ _getWidgets

    /**
     * Get widgets list
     *
     * @return array
     */
    protected function _getWidgets()
    {
      $args = array(
        'orderby'        => 'post_title',
        'order'          => 'ASC',
        'post_type'      => 'ipeng_widget',
        'post_status'    => array('publish'),
        'posts_per_page' => -1,
        'paged'          => 1
      );
      $query = new WP_Query;
      $widgets  = $query->query( $args );
      return $widgets;
    }

    //}}
  }
}
